@@ -12,6 +12,7 @@ from slither.core.declarations.solidity_variables import SolidityVariableCompose
 from slither.core.expressions import NewContract
 from slither.core.slither_core import Slither
 from slither.core.variables.state_variable import StateVariable
+from slither.core.variables.variable import Variable
 from slither.printers.abstract_printer import AbstractPrinter
 from slither.slithir.operations import Member, Operation, SolidityCall, LowLevelCall, HighLevelCall, EventCall, Send, \
     Transfer, InternalDynamicCall, InternalCall, TypeConversion, Balance
@@ -22,7 +23,7 @@ from slither.slithir.variables import Constant
 def _get_name(f: Function) -> str:
     if f.is_fallback or f.is_receive:
         return f'()'
-    return f.full_name
+    return f.solidity_signature
 
 
 def _extract_payable(slither: Slither) -> Dict[str, List[str]]:
@@ -79,7 +80,7 @@ def _is_constant(f: Function) -> bool:
                                                             SolidityFunction('suicide(address)')]:
             return False
         if isinstance(ir, HighLevelCall):
-            if ir.function.view or ir.function.pure:
+            if isinstance(ir.function, Variable) or ir.function.view or ir.function.pure:
                 # External call to constant functions are ensured to be constant only for solidity >= 0.5
                 if f.contract.slither.crytic_compile.compiler_version.version.startswith('0.4'):
                     return False
@@ -129,7 +130,10 @@ def json_serializable(cls):
 
 @json_serializable
 class ConstantValue(NamedTuple):
-    value: Union[str, int, bool]
+    # Here value should be  Union[str, int, bool]
+    # But the json lib in Echidna does not handle large integer in json
+    # So we convert everything to string
+    value: str
     type: str
 
 
@@ -141,17 +145,17 @@ def _extract_constants_from_irs(irs: List[Operation],
         if isinstance(ir, Binary):
             for r in ir.read:
                 if isinstance(r, Constant):
-                    all_cst_used_in_binary[BinaryType.str(ir.type)].append(ConstantValue(r.value, str(r.type)))
+                    all_cst_used_in_binary[BinaryType.str(ir.type)].append(ConstantValue(str(r.value), str(r.type)))
         if isinstance(ir, TypeConversion):
             if isinstance(ir.variable, Constant):
-                all_cst_used.append(ConstantValue(ir.variable.value, str(ir.type)))
+                all_cst_used.append(ConstantValue(str(ir.variable.value), str(ir.type)))
                 continue
         for r in ir.read:
             # Do not report struct_name in a.struct_name
             if isinstance(ir, Member):
                 continue
             if isinstance(r, Constant):
-                all_cst_used.append(ConstantValue(r.value, str(r.type)))
+                all_cst_used.append(ConstantValue(str(r.value), str(r.type)))
             if isinstance(r, StateVariable):
                 if r.node_initialization:
                     if r.node_initialization.irs:
