@@ -2,8 +2,8 @@
     Module printing summary of the contract
 """
 
-from prettytable import PrettyTable
 from slither.printers.abstract_printer import AbstractPrinter
+from slither.utils.myprettytable import MyPrettyTable
 
 
 class FunctionSummary(AbstractPrinter):
@@ -37,13 +37,13 @@ class FunctionSummary(AbstractPrinter):
             txt = "\nContract %s"%name
             txt += '\nContract vars: '+str(var)
             txt += '\nInheritance:: '+str(inheritance)
-            table = PrettyTable(["Function",
-                                 "Visibility",
-                                 "Modifiers",
-                                 "Read",
-                                 "Write",
-                                 "Internal Calls",
-                                 "External Calls"])
+            table = MyPrettyTable(["Function",
+                                  "Visibility",
+                                   "Modifiers",
+                                   "Read",
+                                   "Write",
+                                   "Internal Calls",
+                                  "External Calls"])
             for (_c_name, f_name, visi, modifiers, read, write, internal_calls, external_calls) in func_summaries:
                 read = self._convert(read)
                 write = self._convert(write)
@@ -51,12 +51,12 @@ class FunctionSummary(AbstractPrinter):
                 external_calls = self._convert(external_calls)
                 table.add_row([f_name, visi, modifiers, read, write, internal_calls, external_calls])
             txt += "\n \n"+str(table)
-            table = PrettyTable(["Modifiers",
-                                 "Visibility",
-                                 "Read",
-                                 "Write",
-                                 "Internal Calls",
-                                 "External Calls"])
+            table = MyPrettyTable(["Modifiers",
+                                   "Visibility",
+                                   "Read",
+                                   "Write",
+                                   "Internal Calls",
+                                   "External Calls"])
             for (_c_name, f_name, visi, _, read, write, internal_calls, external_calls) in modif_summaries:
                 read = self._convert(read)
                 write = self._convert(write)
